@@ -256,6 +256,8 @@ def wineexec(executable, args="", wine_path=None, prefix=None, arch=None,
     if use_lutris_runtime(wine_path=wineenv['WINE'], force_disable=disable_runtime):
         if WINE_DIR in wine_path:
             wine_root_path = os.path.dirname(os.path.dirname(wine_path))
+        elif WINE_DIR in winetricks_wine:
+            wine_root_path = os.path.dirname(os.path.dirname(winetricks_wine))
         else:
             wine_root_path = None
         wineenv['LD_LIBRARY_PATH'] = ':'.join(runtime.get_paths(
@@ -818,6 +820,15 @@ class wine(Runner):
                 'advanced': True,
                 'help': "Sets WINEDLLOVERRIDES when launching the game."
             },
+            {
+                'option': 'autoconf_joypad',
+                'type': 'bool',
+                'label': 'Autoconfigure joypads',
+                'advanced': True,
+                'default': True,
+                'help': ('Automatically disables one of Wine\'s detected joypad '
+                         'to avoid having 2 controllers detected')
+            },
             {
                 'option': 'sandbox',
                 'type': 'bool',
@@ -1027,7 +1038,8 @@ class wine(Runner):
         if not os.path.exists(os.path.join(self.prefix_path, 'user.reg')):
             create_prefix(self.prefix_path, arch=self.wine_arch)
         prefix_manager = WinePrefixManager(self.prefix_path)
-        prefix_manager.configure_joypads()
+        if self.runner_config.get('autoconf_joypad', True):
+            prefix_manager.configure_joypads()
         self.sandbox(prefix_manager)
         self.set_regedit_keys()
         self.setup_x360ce(self.runner_config.get('x360ce-path'))
